<div class="progress">
  <div class="progress-bar progress-bar-success" style="width: {{ candidate.votes.0 }}%">
    <span class="sr-only">{{ candidate.votes.0 }}%</span>
  </div>
  <div class="progress-bar progress-bar-success progress-bar-striped" style="width: {{ candidate.votes.1 }}%">
    <span class="sr-only">{{ candidate.votes.1 }}%</span>
  </div>
  <div class="progress-bar progress-bar-info" style="width: {{ candidate.votes.2 }}%">
    <span class="sr-only">{{ candidate.votes.2 }}%</span>
  </div>
  <div class="progress-bar progress-bar-info progress-bar-striped" style="width: {{ candidate.votes.3 }}%">
    <span class="sr-only">{{ candidate.votes.3 }}%</span>
  </div>
  <div class="progress-bar progress-bar-warning" style="width: {{ candidate.votes.4 }}%">
    <span class="sr-only">{{ candidate.votes.4 }}%/span>
  </div>
  <div class="progress-bar progress-bar-danger" style="width: {{ candidate.votes.5 }}%">
    <span class="sr-only">{{ candidate.votes.5 }}%/span>
  </div>
</div>
