{% extends "base.html" %}


{% block content %}
<ul>
  {% for election in election_list %}
  <li><a href="{{ election.get_absolute_url }}">{{ election }}</a></li>
  {% endfor %}
  {% if request.user.is_superuser %}
  <li><a href="{% url "jugemaj:create_election" %}">Nouvelle</a></li>
  {% endif %}
</ul>
{% endblock %}
